@@ -3,9 +3,4 @@ from .api import Shazam
 from .converter import Geo
 from .enums import GenreMusic
 
-__all__ = (
-    'Serialize',
-    'Shazam',
-    'Geo',
-    'GenreMusic'
-)
+__all__ = ("Serialize", "Shazam", "Geo", "GenreMusic")
