@@ -1,6 +1,9 @@
+from typing import Union
+
 from shazamio.factory_misc import FACTORY_ARTIST
 from shazamio.factory_misc import FACTORY_TRACK
 from shazamio.models import ArtistInfo
+from shazamio.models import ArtistV2
 from shazamio.models import ResponseTrack
 from shazamio.models import TrackInfo
 from shazamio.models import YoutubeData
@@ -17,7 +20,7 @@ class Serialize:
 
     @classmethod
     def artist(cls, data):
-        return FACTORY_ARTIST.load(data, ArtistInfo)
+        return FACTORY_ARTIST.load(data, Union[ArtistV2, ArtistInfo])
 
     @classmethod
     def full_track(cls, data):
