@@ -12,7 +12,9 @@ SongT = Union[str, pathlib.Path, bytes, bytearray]
 FileT = Union[str, pathlib.Path]
 
 
-async def validate_json(resp: aiohttp.ClientResponse, content_type: str = 'application/json') -> dict:
+async def validate_json(
+    resp: aiohttp.ClientResponse, content_type: str = "application/json"
+) -> dict:
     try:
         return await resp.json(content_type=content_type)
     except ContentTypeError as e:
@@ -21,11 +23,11 @@ async def validate_json(resp: aiohttp.ClientResponse, content_type: str = 'appli
 
 
 async def get_file_bytes(file: FileT) -> bytes:
-    async with aiofiles.open(file, mode='rb') as f:
+    async with aiofiles.open(file, mode="rb") as f:
         return await f.read()
 
 
-async def get_song(data: SongT) -> bytes:
+async def get_song(data: SongT) -> Union[AudioSegment]:
 
     if isinstance(data, (str, pathlib.Path)):
         song_bytes = await get_file_bytes(file=data)
@@ -36,4 +38,3 @@ async def get_song(data: SongT) -> bytes:
 
     if isinstance(data, AudioSegment):
         return data
-
